/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.bean.portlet;

import java.lang.annotation.ElementType;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;

/**
 * This is an annotation that provides a way to specify the Liferay-specific
 * configuration for a single portlet.
 *
 * @author Neil Griffin
 */
@Retention(RetentionPolicy.RUNTIME)
@Target(ElementType.TYPE)
public @interface LiferayPortletConfiguration {

	/**
	 * The portlet name that the portlet configuration is associated with.
	 *
	 * @return The portlet name that the portlet configuration is associated
	 *         with.
	 */
	public String portletName();

	/**
	 * The Liferay-specific portlet configuration. For more information see the
	 * documentation regarding the <a
	 * href="https://dev.liferay.com/develop/reference/-/knowledge_base/7-1/portlet-descriptor-to-osgi-service-property-map">
	 * Portlet Descriptor to OSGi Service Property Map</a>.
	 *
	 * @return The Liferay-specific portlet configuration.
	 */
	public String[] properties() default {};

}